@@ -1,31 +1,30 @@
 package Geo::Coordinates::OSGB::Grid;
 
 use Geo::Coordinates::OSGB::Maps qw{%maps %name_for_map_series};
-use Geo::Coordinates::OSGB qw{is_grid_in_ostn02};
 
 use base qw(Exporter);
 use strict;
 use warnings;
 use Carp;
-use 5.008; # At least Perl 5.8 please
+use 5.010; # At least Perl 5.10 please, be sure to change POD below if you update
 
-our $VERSION = '2.16';
+our $VERSION = '2.20';
 
-our %EXPORT_TAGS = (all => [qw( 
-        parse_grid 
+our %EXPORT_TAGS = (all => [qw(
+        parse_grid
         format_grid
 
-        parse_trad_grid 
-        parse_GPS_grid 
+        parse_trad_grid
+        parse_GPS_grid
         parse_landranger_grid
         parse_map_grid
-        
-        format_grid_trad 
-        format_grid_GPS 
+
+        format_grid_trad
+        format_grid_GPS
         format_grid_landranger
         format_grid_map
-        
-        random_grid 
+
+        random_grid
         )]);
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{all} } );
@@ -38,11 +37,11 @@ use constant MAJOR_GRID_SQ_EASTING_OFFSET  => 2 * MAJOR_GRID_SQ_SIZE;
 use constant MAJOR_GRID_SQ_NORTHING_OFFSET => 1 * MAJOR_GRID_SQ_SIZE;
 use constant MAX_GRID_SIZE => MINOR_GRID_SQ_SIZE * length GRID_SQ_LETTERS;
 
-# Produce a random GR 
+# Produce a random GR
 # A simple approach would pick 0 < E < 700000 and 0 < N < 1250000 but that way
 # many GRs produced would be in the sea, so pick a random map, and then find a
 # random GR within its bbox and finally check that the resulting pair is
-# inside the OSTN02 boundary and actually on some map.
+# and actually on the map.
 
 sub random_grid {
     my @preferred_sheets = @_;
@@ -59,15 +58,16 @@ sub random_grid {
     else {
         @sheets = keys %maps;
     }
-    my ($map, $lle, $lln, $ure, $urn, $easting, $northing);
+    my ($map, $lle, $lln, $ure, $urn);
+    my ($easting, $northing);
     while (1) {
         $map = $maps{$sheets[int rand @sheets]};
         ($lle, $lln) = @{$map->{bbox}->[0]};
         ($ure, $urn) = @{$map->{bbox}->[1]};
-        $easting  = sprintf "%.3f", $lle + rand ($ure-$lle);
-        $northing = sprintf "%.3f", $lln + rand ($urn-$lln);
-        last if is_grid_in_ostn02($easting, $northing) 
-             && 0 != _winding_number($easting, $northing, $map->{polygon});
+        $easting  = sprintf '%.3f', $lle + rand ($ure-$lle);
+        $northing = sprintf '%.3f', $lln + rand ($urn-$lln);
+        # check we are actually on the chosen map
+        last if _winding_number($easting, $northing, $map->{polygon});
     }
     return ($easting, $northing);
 }
@@ -93,13 +93,13 @@ sub format_grid {
             if ($m->{bbox}->[0][0] <= $easting  && $easting  < $m->{bbox}->[1][0]
              && $m->{bbox}->[0][1] <= $northing && $northing < $m->{bbox}->[1][1]) {
                 my $w = _winding_number($easting, $northing, $m->{polygon});
-                if ($w != 0) { 
+                if ($w != 0) {
                     push @sheets, $k;
                 }
             }
         }
         @sheets = sort @sheets;
-    } 
+    }
 
     # special cases
     if ( $form eq 'TRAD' ) {
@@ -122,12 +122,12 @@ sub format_grid {
             return ($sq, $e, $n, @sheets)
         }
 
-        my $gr = sprintf "%s%s%0.*d%s%0.*d", $sq, $space_a, $e_len, $e, $space_b, $n_len, $n;
+        my $gr = sprintf '%s%s%0.*d%s%0.*d', $sq, $space_a, $e_len, $e, $space_b, $n_len, $n;
         $gr =~ s/\s+/ /g;
 
         if ( $with_maps ) {
             if ( @sheets ) {
-                return sprintf '%s on %s', $gr, join ', ', @sheets; 
+                return sprintf '%s on %s', $gr, join ', ', @sheets;
             }
             else {
                 return sprintf '%s is not on any maps in series %s', $gr, $map_keys;
@@ -170,7 +170,7 @@ sub format_grid_landranger {
     for my $s (@sheets) {
         $s =~ s/\AA://xsm;
     }
-    
+
     return ($sq, $e, $n, @sheets) if wantarray;
 
     if (!@sheets )    { return sprintf '%s %03d %03d is not on any Landranger sheet', $sq, $e, $n }
@@ -184,7 +184,7 @@ sub format_grid_landranger {
 
 sub _grid_to_sq {
     my ($e, $n) = @_;
-    
+
     $e += MAJOR_GRID_SQ_EASTING_OFFSET;
     $n += MAJOR_GRID_SQ_NORTHING_OFFSET;
     return if !(0 <= $e && $e < MAX_GRID_SIZE && 0 <= $n && $n < MAX_GRID_SIZE);
@@ -193,15 +193,15 @@ sub _grid_to_sq {
     $e = $e % MAJOR_GRID_SQ_SIZE;
     $n = $n % MAJOR_GRID_SQ_SIZE;
     my $minor_index = int $e / MINOR_GRID_SQ_SIZE + GRID_SIZE * int $n / MINOR_GRID_SQ_SIZE;
-    return 
+    return
        substr(GRID_SQ_LETTERS, $major_index, 1) .
        substr(GRID_SQ_LETTERS, $minor_index, 1);
 }
 
 sub _get_grid_square_offsets {
     my $s = shift;
-    return unless length $s > 1;
-    
+    return if length $s < 2;
+
     my $a = index GRID_SQ_LETTERS, uc substr $s, 0, 1;
     return if 0 > $a;
 
@@ -212,7 +212,7 @@ sub _get_grid_square_offsets {
     my ($x, $y) = ($b % GRID_SIZE, int $b / GRID_SIZE);
 
     return (
-        MAJOR_GRID_SQ_SIZE * $X - MAJOR_GRID_SQ_EASTING_OFFSET  + MINOR_GRID_SQ_SIZE * $x, 
+        MAJOR_GRID_SQ_SIZE * $X - MAJOR_GRID_SQ_EASTING_OFFSET  + MINOR_GRID_SQ_SIZE * $x,
         MAJOR_GRID_SQ_SIZE * $Y - MAJOR_GRID_SQ_NORTHING_OFFSET + MINOR_GRID_SQ_SIZE * $y
     );
 }
@@ -222,13 +222,13 @@ sub _get_eastnorthings {
     my $numbers = $s;
     $numbers =~ tr/0-9//cd; # avoid using "r" here as it requires perl >= 5.14
     my $len = length $numbers;
-    croak "No easting or northing found" if $len == 0;
+    croak 'No easting or northing found' if $len == 0;
     croak "Easting and northing have different lengths in $s" if $len % 2;
     croak "Too many digits in $s" if $len > 10;
 
     # this trick lets us pad with zeros on the right
-    my $e = reverse sprintf "%05d", scalar reverse substr $numbers, 0, $len/2;
-    my $n = reverse sprintf "%05d", scalar reverse substr $numbers,    $len/2;
+    my $e = reverse sprintf '%05d', scalar reverse substr $numbers, 0, $len/2;
+    my $n = reverse sprintf '%05d', scalar reverse substr $numbers,    $len/2;
     return ($e, $n)
 }
 
@@ -240,7 +240,7 @@ sub parse_grid {
 
     my @out;
 
-    my $s = @_ < 3 ? "@_" : sprintf "%s %0.*d %0.*d", $_[0], $figs, $_[1], $figs, $_[2];
+    my $s = @_ < 3 ? "@_" : sprintf '%s %0.*d %0.*d', $_[0], $figs, $_[1], $figs, $_[2];
 
     # normal case : TQ 123 456 etc
     if ( my ($E, $N) = _get_grid_square_offsets($s) ) {
@@ -250,24 +250,33 @@ sub parse_grid {
     }
 
     # sheet id instead of grid sq
-    if (my ($sheet, $numbers) = $s =~ m{\A ([A-Z0-9:./]+)\D+(\d+\D*\d+) \Z }xsmio ) {
+    my $sheet_ref_pattern = qr{\A([A-Z]:)?([0-9NEWSOL/]+?)(\.[a-z]+)?(?:[ -/.]([ 0-9]+))?\Z};
+    my ($prefix, $sheet, $suffix, $numbers) = $s =~ m/$sheet_ref_pattern/sioxm;
 
-        # allow Landranger sheets with no prefix
-        $sheet = "A:$sheet" if exists $maps{"A:$sheet"};
+    if (defined $sheet) {
 
-        if ( exists $maps{$sheet} ) { 
-            my @ll_corner = @{$maps{$sheet}->{bbox}[0]};  # NB we need the bbox corner so that it is left and below all points on the map
+        if ( ! defined $prefix ) {
+            $prefix = 'A:';
+        }
+        if ( ! defined $suffix ) {
+            $suffix = q{};
+        }
+        $sheet = $prefix . $sheet . $suffix;
 
-            my ($e, $n) = _get_eastnorthings($numbers);
+        if (exists $maps{$sheet}) {
+            my ($E, $N)  = @{$maps{$sheet}->{bbox}[0]};  # NB we need the bbox corner so that it is left and below all points on the map
 
-            $e = $ll_corner[0] + ($e-$ll_corner[0]) % MINOR_GRID_SQ_SIZE;
-            $n = $ll_corner[1] + ($n-$ll_corner[1]) % MINOR_GRID_SQ_SIZE;
+            if (defined $numbers) {
+                my ($e, $n) = _get_eastnorthings($numbers);
+                $E = $E + ($e-$E) % MINOR_GRID_SQ_SIZE;
+                $N = $N + ($n-$N) % MINOR_GRID_SQ_SIZE;
 
-            my $w = _winding_number($e, $n, $maps{$sheet}->{polygon});
-            if ($w == 0) {
-                croak sprintf "Grid reference %s = (%d, %d) is not on sheet %s", scalar format_grid($e,$n), $e, $n, $sheet;
+                my $w = _winding_number($E, $N, $maps{$sheet}->{polygon});
+                if ($w == 0) {
+                    croak sprintf 'Grid reference %s = (%d, %d) is not on sheet %s', scalar format_grid($E,$N), $e, $n, $sheet;
+                }
             }
-            return wantarray ? ($e, $n) : "$e $n";
+            return wantarray ? ($E, $N) : "$E $N";
         }
     }
 
@@ -321,20 +330,20 @@ Geo::Coordinates::OSGB::Grid - Format and parse British National Grid references
 
 =head1 VERSION
 
-2.16
+2.20
 
 =head1 SYNOPSIS
 
   use Geo::Coordinates::OSGB::Grid qw/parse_grid format_grid/;
 
   my ($e,$n) = parse_grid('TQ 23451 09893');
-  my $gr     = format_grid($e, $n); # "TQ 234 098"     
+  my $gr     = format_grid($e, $n); # "TQ 234 098"
 
 =head1 DESCRIPTION
 
 This module provides useful functions for parsing and formatting OSGB
 grid references.  Some detailed background is given in C<background.pod>
-and on the OS web site.  
+and on the OS web site.
 
 =head1 SUBROUTINES AND METHODS
 
@@ -342,7 +351,7 @@ and on the OS web site.
 
 Formats an (easting, northing) pair into traditional `full national grid
 reference' with two letters and two sets of three numbers, like this `SU
-387 147'.  
+387 147'.
 
     $gridref = format_grid(438710.908, 114792.248); # SU 387 147
 
@@ -365,18 +374,18 @@ one or more of the keys shown below (with the default values).
 
 =over 4
 
-=item form  
+=item form
 
 Controls the format of the grid reference.  With C<$e, $n> set as above:
 
-    Format          produces        Format            produces       
+    Format          produces        Format            produces
     ----------------------------------------------------------------
     'SS'            SU
-    'SSEN'          SU31            'SS E N'          SU 3 1         
-    'SSEENN'        SU3814          'SS EE NN'        SU 38 14       
-    'SSEEENNN'      SU387147        'SS EEE NNN'      SU 387 147     
-    'SSEEEENNNN'    SU38711479      'SS EEEE NNNN'    SU 3871 1479 
-    'SSEEEEENNNNN'  SU3871014792    'SS EEEEE NNNNN'  SU 38710 14792 
+    'SSEN'          SU31            'SS E N'          SU 3 1
+    'SSEENN'        SU3814          'SS EE NN'        SU 38 14
+    'SSEEENNN'      SU387147        'SS EEE NNN'      SU 387 147
+    'SSEEEENNNN'    SU38711479      'SS EEEE NNNN'    SU 3871 1479
+    'SSEEEEENNNNN'  SU3871014792    'SS EEEEE NNNNN'  SU 38710 14792
 
 You can't leave out the SS, you can't have N before E, and there must be
 the same number of Es and Ns.
@@ -394,7 +403,7 @@ you want just the local easting and northing without the grid square,
 get the individual parts in a list context and format them yourself:
 
     my $gr = sprintf('Grid ref %2$s %3$s on Sheet %4$s', format_grid_landranger($e, $n))
-    # returns: Grid ref 387 147 on Sheet 196 
+    # returns: Grid ref 387 147 on Sheet 196
 
 =item maps
 
@@ -429,7 +438,7 @@ C<J> : Harvey Super Walker maps - mainly at 1:25000
 
 so if you only want Explorer maps use: C<< series => 'B' >>, and if you
 want only Explorers and Landrangers use: C<< series => 'AB' >>, and so
-on. 
+on.
 
 Note that the numbers returned for the Harvey maps have been invented
 for the purposes of this module.  They do not appear on the maps
@@ -437,7 +446,7 @@ themselves; instead the maps have titles.  You can use the numbers
 returned as an index to the data in L<Geo::Coordinates::OSGB::Maps> to
 find the appropriate title.
 
-=back 
+=back
 
 =head2 C<format_grid_trad(e,n)>
 
@@ -455,7 +464,7 @@ Equivalent to C<< format_grid(e,n, { maps => 1 }) >>.
 
 Equivalent to
 
-   format_grid(e,n,{ form => 'ss eee nnn', maps => 1, series => 'A' }) 
+   format_grid(e,n,{ form => 'ss eee nnn', maps => 1, series => 'A' })
 
 except that the leading "A:" will be stripped from any sheet names
 returned, and you get a slightly fancier set of phrases in a scalar
@@ -464,8 +473,8 @@ context depending on how many map numbers are in the list of sheets.
 
 =head2 C<parse_grid>
 
-The C<parse_grid> routine extracts a (easting, northing) pair from a
-string, or a list of arguments, representing a grid reference.  The pair
+The C<parse_grid> routine extracts an (easting, northing) pair from a
+string or a list of arguments representing a grid reference.  The pair
 returned are in units of metres from the false origin of the grid, so
 that you can pass them to C<format_grid> or C<grid_to_ll>.
 
@@ -473,14 +482,14 @@ The arguments should be in one of the following forms
 
 =over 4
 
-=item * 
+=item *
 
 A single string representing a grid reference
 
-  String                        ->  interpreted as   
+  String                        ->  interpreted as
   --------------------------------------------------
-  parse_grid("TA 123 678")      ->  (512300, 467800) 
-  parse_grid("TA 12345 67890")  ->  (512345, 467890) 
+  parse_grid("TA 123 678")      ->  (512300, 467800)
+  parse_grid("TA 12345 67890")  ->  (512345, 467890)
 
 The spaces are optional in all cases.  You can also refer to a 100km
 square as C<TA> which will return C<(500000,400000)>, a 10km square as
@@ -489,17 +498,17 @@ as C<TA1267> which gives C<(512000, 467000)>.  For completeness you can
 also use C<TA 1234 6789> to refer to a decametre square C<(512340,
 467890)> but you might struggle to find a use for that one.
 
-=item * 
+=item *
 
 A list representing a grid reference
 
-  List                             ->  interpreted as   
+  List                             ->  interpreted as
   -----------------------------------------------------
-  parse_grid('TA', 0, 0)           ->  (500000, 400000) 
-  parse_grid('TA', 123, 678)       ->  (512300, 467800) 
-  parse_grid('TA', 12345, 67890)   ->  (512345, 467890) 
-  parse_grid('TA', '123 678')      ->  (512300, 467800) 
-  parse_grid('TA', '12345 67890')  ->  (512345, 467890) 
+  parse_grid('TA', 0, 0)           ->  (500000, 400000)
+  parse_grid('TA', 123, 678)       ->  (512300, 467800)
+  parse_grid('TA', 12345, 67890)   ->  (512345, 467890)
+  parse_grid('TA', '123 678')      ->  (512300, 467800)
+  parse_grid('TA', '12345 67890')  ->  (512345, 467890)
 
 If you are processing grid references from some external data source
 beware that if you use a list with bare numbers you may lose any leading
@@ -509,25 +518,25 @@ preserve the leading digits or supply a hash of options as a fourth
 argument with the `figs' option to define how many figures are supposed
 to be in each easting and northing.  Like this:
 
-  List                                     ->  interpreted as   
+  List                                     ->  interpreted as
   -------------------------------------------------------------
-  parse_grid('TA', 123, 8)                 ->  (512300, 400800) 
-  parse_grid('TA', 123, 8, { figs => 5 })  ->  (500123, 400008) 
+  parse_grid('TA', 123, 8)                 ->  (512300, 400800)
+  parse_grid('TA', 123, 8, { figs => 5 })  ->  (500123, 400008)
 
 The default setting of figs is 3, which assumes you are using
 hectometres as in a traditional grid reference.
 
-=item * 
+=item *
 
 A string or list representing a map sheet and a grid reference on that
 sheet
 
-     Map input                      ->  interpreted as    
+     Map input                      ->  interpreted as
      ----------------------------------------------------
-     parse_grid('A:164/352194')     ->  (435200, 219400) 
-     parse_grid('B:OL43E/914701')   ->  (391400, 570100) 
-     parse_grid('B:OL43E 914 701')  ->  (391400, 570100) 
-     parse_grid('B:OL43E','914701') ->  (391400, 570100) 
+     parse_grid('A:164/352194')     ->  (435200, 219400)
+     parse_grid('B:OL43E/914701')   ->  (391400, 570100)
+     parse_grid('B:OL43E 914 701')  ->  (391400, 570100)
+     parse_grid('B:OL43E','914701') ->  (391400, 570100)
      parse_grid('B:OL43E',914,701)  ->  (391400, 570100)
 
 Again spaces are optional, but you need some non-digit between the map
@@ -541,23 +550,25 @@ more than one.  The given example would fail if the map was given as
 If you give the identifier as just a number, it's assumed that you
 wanted a Landranger map;
 
-     parse_grid('176/224711')  ->  (522400, 171100) 
-     parse_grid(164,513,62)    ->  (451300, 206200) 
+     parse_grid('176/224711')  ->  (522400, 171100)
+     parse_grid(164,513,62)    ->  (451300, 206200)
 
-The routine will croak of you pass it a sheet identifier that is not
+C<parse_grid> will croak of you pass it a sheet identifier that is not
 defined in L<Geo::Coordinates::OSGB::Maps>.  It will also croak if the
 supplied easting and northing are not actually on the sheet.
 
-In earlier versions, the easting and northing arguments were optional,
-and you could leave them out to get just the SW corner of the sheet.
-This functionality has been removed in this version, because it's not
-always obvious where the SW corner of a sheet is (for an example look at
-the inset on Landranger sheet 107).
+If you just want the corner of a particular map, just pass the sheet name:
 
-If you need access to the position of the sheets in this version, you
+     parse_grid('A:82')        -> (195000, 530000)
+     parse_grid(161)           -> (309000, 205000)
+
+Again, it's assumed that you want a Landranger map.  The grid reference returned
+is the SW corner of the particular sheet.  This is usually obvious, but less so
+for some of the oddly shaped 1:25000 sheets, or Harvey's maps.  What you actually get
+is the first point defined in the maps polygon, as defined in Maps.  If in doubt you
 should work directly with the data in L<Geo::Coordinates::OSGB::Maps>.
 
-=back  
+=back
 
 =head2 C<parse_trad_grid(grid_ref)>
 
@@ -581,28 +592,27 @@ synonym for C<parse_grid>.
 
 =head2 C<random_grid([sheet1, sheet2, ...])>
 
-Takes an optional list of map sheet identifiers, and returns a random
-easting and northing for some place covered by one of the maps.  There's
-no guarantee that the point will not be in the sea, but it will be
-within the bounding box of one of the maps and it should be within one
-of the areas covered by the OSTN02 data set.
+Takes an optional list of map sheet identifiers, and returns a random easting
+and northing for some place covered by one of the maps.  There's no guarantee
+that the point will not be in the sea, but it will be within the bounding box
+of one of the maps.
 
 =over 4
 
 =item *
 
 If you omit the list of sheets, then one of map sheets defined in
-L<Geo::Coordinates::OSGB::Maps> will be picked at random.  
+L<Geo::Coordinates::OSGB::Maps> will be picked at random.
 
 =item *
 
 As a convenience whole numbers in the range 1..204 will be interpreted
-as Landranger sheets, as if you had written C<A:1>, C<A:2>, etc. 
+as Landranger sheets, as if you had written C<A:1>, C<A:2>, etc.
 
 =item *
 
 Any sheet identifiers in the list that are not defined in
-L<Geo::Coordinates::OSGB::Maps> will be (silently) ignored.  
+L<Geo::Coordinates::OSGB::Maps> will be (silently) ignored.
 
 =item *
 
@@ -614,9 +624,9 @@ that they are suitable for input to the C<format_grid> routines.
 
 =head1 EXAMPLES
 
-  use Geo::Coordinates::OSGB::Grid 
-     qw/parse_grid 
-        format_grid 
+  use Geo::Coordinates::OSGB::Grid
+     qw/parse_grid
+        format_grid
         format_grid_landranger/;
 
   # Get full coordinates in metres from GR
@@ -624,10 +634,10 @@ that they are suitable for input to the C<format_grid> routines.
 
   # Reading and writing grid references
   # Format full easting and northing into traditional formats
-  my $gr1 = format_grid($e, $n);                              # "TQ 234 098"     
-  my $gr2 = format_grid($e, $n, { form => 'SSEEENNN' } );     # "TQ234098"       
-  my $gr3 = format_grid($e, $n, { form => 'SSEEEEENNNNN'} );  # "TQ 23451 09893" 
-  my $gr4 = format_grid($e, $n, { form => 'gps'} );           # "TQ 23451 09893" 
+  my $gr1 = format_grid($e, $n);                              # "TQ 234 098"
+  my $gr2 = format_grid($e, $n, { form => 'SSEEENNN' } );     # "TQ234098"
+  my $gr3 = format_grid($e, $n, { form => 'SSEEEEENNNNN'} );  # "TQ 23451 09893"
+  my $gr4 = format_grid($e, $n, { form => 'gps'} );           # "TQ 23451 09893"
   my $gr5 = format_grid_landranger($e, $n);# "TQ 234 098 on Landranger sheet 198"
 
   # or call in list context to get the individual parts
@@ -642,7 +652,7 @@ that they are suitable for input to the C<format_grid> routines.
   # You can also get grid refs from individual maps.
   # Sheet between 1..204; gre & grn must be 3 or 5 digits long
   ($e,$n) = parse_grid(176,123,994);
-  # put leading zeros in quotes 
+  # put leading zeros in quotes
   ($e,$n) = parse_grid(196,636,'024');
 
 For more examples of parsing and formatting look at the test files.
@@ -650,11 +660,14 @@ For more examples of parsing and formatting look at the test files.
 =head1 BUGS AND LIMITATIONS
 
 The useful area of these routines is confined to the British Isles, not
-including Ireland or the Channel Islands.  But very little range
-checking is done, so you can generate pseudo grid references for points
-that are some way outside this useful area.  The corners of this larger
-area run from 64.75N 32.33W (Iceland) to 65.8N 22.65E (Norway) to 44.5N
-11.8E (Venice) to 44N 19.5W (the Western Approaches). 
+including Ireland or the Channel Islands.  But very little range checking is
+done, so you can generate pseudo grid references for points that are some way
+outside this useful area.  For example we have St Peter Port in Guernsey at
+C<XD 611 506> and Rockall at C<MC 035 165>.  The working area runs from square
+C<AA> in the far north west to C<ZZ> in the far south east.  In WGS84 terms the
+corners run from 64.75N 32.33W (Iceland) to 65.8N 22.65E (Norway) to 44.5N
+11.8E (Venice) to 44N 19.5W (the Western Approaches).  This is something of a
+geodesy toy rather than a useful function.
 
 =head1 DIAGNOSTICS
 
@@ -672,7 +685,7 @@ Format ... was not recognized
 The format code you supplied with C<< { form => ... } >> did not match
 any of the expected patterns.
 
-=item * 
+=item *
 
 Too far off the grid: ...
 
@@ -695,7 +708,7 @@ No easting or northing found
 This means you passed something more than a 2-letter grid square but
 there were no numbers found in the latter part of the string.
 
-=item * 
+=item *
 
 Easting and northing have different lengths in ...
 
@@ -724,7 +737,7 @@ your input.
 
 =back
 
-If you get an expected result from any of these subroutines, please
+If you get an unexpected result from any of these subroutines, please
 generate a test case to reproduce your result and get in touch to ask me
 about it.
 
@@ -732,11 +745,11 @@ about it.
 
 There is no configuration required either of these modules or your
 environment.  It should work on any recent version of Perl better than
-5.8, on any platform.
+5.10, on any platform.
 
 =head1 DEPENDENCIES
 
-Perl 5.08 or better.
+Perl 5.10 or better.
 
 =head1 INCOMPATIBILITIES
 
@@ -744,7 +757,7 @@ None known.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2002-2016 Toby Thurston
+Copyright (C) 2002-2017 Toby Thurston
 
 OSTN02 transformation data included in this module is freely available
 from the Ordnance Survey but remains Crown Copyright (C) 2002
@@ -765,12 +778,12 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 
 =head1 AUTHOR
 
-Toby Thurston -- 16 Feb 2016 
+Toby Thurston -- 30 Jul 2017
 
 toby@cpan.org
 
 =head1 SEE ALSO
 
-See L<Geo::Coordinates::OSGB>. 
+See L<Geo::Coordinates::OSGB>.
 
 =cut
